From d76cc24eab442c84ed3659e014649267f2e430d3 Mon Sep 17 00:00:00 2001
From: Thomas Hartmann <Thomas.Hartmann@nokia.com>
Date: Fri, 29 Jan 2010 16:38:34 +0100
Subject: [PATCH] QmlDesigner.propertyEditor: move widgets from Qt 4.6 to
 Bauhaus 1.0 We should not polute the Qml Qt 4.6 namespace

See BAUHAUS-322
---
 .../propertyeditor/Qt/AnchorBox.qml           |  1 +
 .../propertyeditor/Qt/CheckBox.qml            |  1 +
 .../propertyeditor/Qt/Geometry.qml            |  1 +
 .../propertyeditor/Qt/HorizontalLine.qml      |  1 +
 .../propertyeditor/Qt/HorizontalWhiteLine.qml |  1 +
 .../qmldesigner/propertyeditor/Qt/Layout.qml  |  1 +
 .../propertyeditor/Qt/Modifiers.qml           |  1 +
 .../propertyeditor/Qt/PropertyFrame.qml       |  1 +
 .../propertyeditor/Qt/Switches.qml            |  1 +
 .../qmldesigner/propertyeditor/Qt/Type.qml    |  1 +
 .../propertyeditor/basicwidgets.cpp           | 92 +++++++++----------
 11 files changed, 56 insertions(+), 46 deletions(-)

diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/AnchorBox.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/AnchorBox.qml
index b8920256173..e346ba58ad3 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/AnchorBox.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/AnchorBox.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 QWidget {
     width:220;fixedWidth:  width
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/CheckBox.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/CheckBox.qml
index ff3c8e66e1b..8f3babe1ba3 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/CheckBox.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/CheckBox.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 QCheckBox { //This is a special CheckBox that does color coding for states
    id: CheckBox;
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/Geometry.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/Geometry.qml
index 6601b878de8..f22f07e4e9d 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/Geometry.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/Geometry.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 GroupBox {
     finished: finishedNotify;
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalLine.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalLine.qml
index b1f64185674..d046ee2e777 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalLine.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalLine.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
     QLineEdit {
     text:  "";
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalWhiteLine.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalWhiteLine.qml
index b8e1e31b878..00e688380a5 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalWhiteLine.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/HorizontalWhiteLine.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
     QLineEdit {
     text:  "";
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/Layout.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/Layout.qml
index c8c505f932e..3f5b7003b05 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/Layout.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/Layout.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 GroupBox {
     finished: finishedNotify;
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/Modifiers.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/Modifiers.qml
index b46f8a4f9e6..11b87b54576 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/Modifiers.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/Modifiers.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 GroupBox {
     finished: finishedNotify;
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/PropertyFrame.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/PropertyFrame.qml
index 5356e4291ee..220eed573cb 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/PropertyFrame.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/PropertyFrame.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 WidgetFrame {
    id: PropertyFrame;
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/Switches.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/Switches.qml
index f054873146b..4a95ae0f96d 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/Switches.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/Switches.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 QFrame {
     styleSheetFile: "switch.css";
diff --git a/share/qtcreator/qmldesigner/propertyeditor/Qt/Type.qml b/share/qtcreator/qmldesigner/propertyeditor/Qt/Type.qml
index 4dfd15083dc..59492942488 100644
--- a/share/qtcreator/qmldesigner/propertyeditor/Qt/Type.qml
+++ b/share/qtcreator/qmldesigner/propertyeditor/Qt/Type.qml
@@ -1,4 +1,5 @@
 import Qt 4.6
+import Bauhaus 1.0
 
 GroupBox {
     id: Type;
diff --git a/src/plugins/qmldesigner/components/propertyeditor/basicwidgets.cpp b/src/plugins/qmldesigner/components/propertyeditor/basicwidgets.cpp
index 2768ccd1f77..f720fc8278d 100644
--- a/src/plugins/qmldesigner/components/propertyeditor/basicwidgets.cpp
+++ b/src/plugins/qmldesigner/components/propertyeditor/basicwidgets.cpp
@@ -1119,63 +1119,63 @@ public:
     {}
 };
 
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QWidget,QWidget,QWidgetDeclarativeUI);
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QWidget,QWidget,QWidgetDeclarativeUI);
 
 //display
-QML_DEFINE_TYPE(Qt,4,6,QLabel,QLabel);
-QML_DEFINE_TYPE(Qt,4,6,QProgressBar,QProgressBar);
-QML_DEFINE_TYPE(Qt,4,6,QLCDNumber,QLCDNumber);
+QML_DEFINE_TYPE(Bauhaus,1,0,QLabel,QLabel)
+QML_DEFINE_TYPE(Bauhaus,1,0,QProgressBar,QProgressBar)
+QML_DEFINE_TYPE(Bauhaus,1,0,QLCDNumber,QLCDNumber)
 
 //input
-QML_DEFINE_TYPE(Qt,4,6,QLineEdit,QLineEdit);
-QML_DEFINE_TYPE(Qt,4,6,QTextEdit,QTextEdit);
-QML_DEFINE_TYPE(Qt,4,6,QPlainTextEdit,QPlainTextEdit);
-QML_DEFINE_TYPE(Qt,4,6,QSpinBox,QSpinBox);
-QML_DEFINE_TYPE(Qt,4,6,QDoubleSpinBox,QDoubleSpinBox);
-QML_DEFINE_TYPE(Qt,4,6,QSlider,QSlider);
-QML_DEFINE_TYPE(Qt,4,6,QDateTimeEdit,QDateTimeEdit);
-QML_DEFINE_TYPE(Qt,4,6,QDateEdit,QDateEdit);
-QML_DEFINE_TYPE(Qt,4,6,QTimeEdit,QTimeEdit);
-QML_DEFINE_TYPE(Qt,4,6,QFontComboBox,QFontComboBox);
-QML_DEFINE_TYPE(Qt,4,6,QDial,QDial);
-QML_DEFINE_TYPE(Qt,4,6,QScrollBar,QScrollBar);
-QML_DEFINE_TYPE(Qt,4,6,QCalendarWidget, QCalendarWidget);
-
-
-QML_DECLARE_TYPE(MyGroupBox);
-QML_DECLARE_TYPE(WidgetLoader);
-QML_DECLARE_TYPE(WidgetFrame);
-//QML_DEFINE_TYPE(Qt,4,6,QComboBox,QComboBox); //need a way to populate
+QML_DEFINE_TYPE(Bauhaus,1,0,QLineEdit,QLineEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QTextEdit,QTextEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QPlainTextEdit,QPlainTextEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QSpinBox,QSpinBox)
+QML_DEFINE_TYPE(Bauhaus,1,0,QDoubleSpinBox,QDoubleSpinBox)
+QML_DEFINE_TYPE(Bauhaus,1,0,QSlider,QSlider)
+QML_DEFINE_TYPE(Bauhaus,1,0,QDateTimeEdit,QDateTimeEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QDateEdit,QDateEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QTimeEdit,QTimeEdit)
+QML_DEFINE_TYPE(Bauhaus,1,0,QFontComboBox,QFontComboBox)
+QML_DEFINE_TYPE(Bauhaus,1,0,QDial,QDial)
+QML_DEFINE_TYPE(Bauhaus,1,0,QScrollBar,QScrollBar)
+QML_DEFINE_TYPE(Bauhaus,1,0,QCalendarWidget, QCalendarWidget)
+
+
+QML_DECLARE_TYPE(MyGroupBox)
+QML_DECLARE_TYPE(WidgetLoader)
+QML_DECLARE_TYPE(WidgetFrame)
+//QML_DEFINE_TYPE(Bauhaus,1,0,QComboBox,QComboBox); //need a way to populate
 //QML_DEFINE_EXTENDED_TYPE(QComboBox,QComboBox, QComboBox); //need a way to populate
 
 //buttons
-//QML_DEFINE_TYPE(Qt,4,6,QPushButton,QPushButton);
-QML_DEFINE_TYPE(Qt,4,6,QCheckBox,QCheckBox);
-QML_DEFINE_TYPE(Qt,4,6,QAction,Action);
-QML_DEFINE_TYPE(Qt,4,6,QRadioButton,QRadioButton);
-QML_DEFINE_TYPE(Qt,4,6,FileWidget, FileWidget);
-QML_DEFINE_TYPE(Qt,4,6,LayoutWidget, LayoutWidget);
+//QML_DEFINE_TYPE(Bauhaus,1,0,QPushButton,QPushButton);
+QML_DEFINE_TYPE(Bauhaus,1,0,QCheckBox,QCheckBox)
+QML_DEFINE_TYPE(Bauhaus,1,0,QAction,Action)
+QML_DEFINE_TYPE(Bauhaus,1,0,QRadioButton,QRadioButton)
+QML_DEFINE_TYPE(Bauhaus,1,0,FileWidget, FileWidget)
+QML_DEFINE_TYPE(Bauhaus,1,0,LayoutWidget, LayoutWidget)
 
 //containers
-QML_DEFINE_TYPE(Qt,4,6,QFrame,QFrame);
-QML_DEFINE_TYPE(Qt,4,6,WidgetFrame,WidgetFrame);
-QML_DEFINE_TYPE(Qt,4,6,WidgetLoader,WidgetLoader);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QExtGroupBox,MyGroupBox,QGroupBoxDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QTabWidget,QTabWidget,QTabWidgetDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QScrollArea,QScrollArea,QScrollAreaDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QPushButton,QPushButton,QPushButtonDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QToolButton,QToolButton, QToolButtonDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QComboBox,QComboBox, QComboBoxDeclarativeUI);
-QML_DEFINE_EXTENDED_TYPE(Qt,4,6,QMenu,QMenu, QMenuDeclarativeUI);
-//QML_DEFINE_TYPE(Qt,4,6,QToolBox,QToolBox);
-//QML_DEFINE_TYPE(Qt,4,6,QScrollArea,QScrollArea);
-
-//QML_DEFINE_EXTENDED_TYPE(QtColorButton,QtColorButton,QtColorButtonDeclarativeUI);
+QML_DEFINE_TYPE(Bauhaus,1,0,QFrame,QFrame)
+QML_DEFINE_TYPE(Bauhaus,1,0,WidgetFrame,WidgetFrame)
+QML_DEFINE_TYPE(Bauhaus,1,0,WidgetLoader,WidgetLoader)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QExtGroupBox,MyGroupBox,QGroupBoxDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QTabWidget,QTabWidget,QTabWidgetDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QScrollArea,QScrollArea,QScrollAreaDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QPushButton,QPushButton,QPushButtonDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QToolButton,QToolButton, QToolButtonDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QComboBox,QComboBox, QComboBoxDeclarativeUI)
+QML_DEFINE_EXTENDED_TYPE(Bauhaus,1,0,QMenu,QMenu, QMenuDeclarativeUI)
+//QML_DEFINE_TYPE(Bauhaus,1,0,BauhausoolBox,BauhausoolBox);
+//QML_DEFINE_TYPE(Bauhaus,1,0,QScrollArea,QScrollArea);
+
+//QML_DEFINE_EXTENDED_TYPE(BauhausColorButton,BauhausColorButton,BauhausColorButtonDeclarativeUI);
 
 //itemviews
-//QML_DEFINE_TYPE(Qt,4,6,QListView,QListView);
-//QML_DEFINE_TYPE(Qt,4,6,QTreeView,QTreeView);
-//QML_DEFINE_TYPE(Qt,4,6,QTableView,QTableView);
+//QML_DEFINE_TYPE(Bauhaus,1,0,QListView,QListView);
+//QML_DEFINE_TYPE(Bauhaus,1,0,BauhausreeView,BauhausreeView);
+//QML_DEFINE_TYPE(Bauhaus,1,0,BauhausableView,BauhausableView);
 
 
 #include "basicwidgets.moc"
-- 
GitLab